qemu-kvm process is running at 100% CPU, but no response from guest
Hello,
today I have second incident, that my qemu-kvm process is running at 100%
or 200% CPU (watched using top program), but there is no response from guest long time (some hours). First time lots of these messages appeared in dmesg:
vcpu not ready for apic_round_robin
vcpu not ready for apic_round_robin
vcpu not ready for apic_round_robin
Second time nothing, only process was run at 200% CPU:
top - 06:23:14 up 4 days, 11:06, 1 user, load average: 2.26, 2.15, 2.18
Tasks: 126 total, 1 running, 125 sleeping, 0 stopped, 0 zombie
Cpu(s): 50.2%us, 0.4%sy, 0.0%ni, 49.1%id, 0.2%wa, 0.0%hi, 0.1%si, 0.0%st
Mem: 8047368k total, 8004516k used, 42852k free, 1507160k buffers Swap: 8388600k total, 57284k used, 8331316k free, 79700k cached
PID USER PR NI VIRT RES SHR S %CPU %MEM TIME+ COMMAND 17110 root 20 0 4417m 3.9g 1464 S 201.3 50.9 1326:34 qemu-kvm 9886 root 20 0 2519m 1.9g 1376 S 1.7 25.1 72:40.73 qemu-kvm
Serial console without response too in boch cases, no ping to guest.
My current configuration is an fully updated Fedora 11 host and updated Fedora 10 guest. KVM is from package qemu-kvm-0.10.5-3.fc11.x86_64.
I have no cpufreq or cpuspeed installed on my system, so there is no cpu frequency scaling.
Other 2 similar host installations have no similar problems.
Thank you for help.
SAL
Quoted 16 lines · Ján ONDREJ (SAL)
Hello,
today I have second incident, that my qemu-kvm process is running at 100%
or 200% CPU (watched using top program), but there is no response from guest long time (some hours). First time lots of these messages appeared in dmesg:vcpu not ready for
apic_round_robin
vcpu not ready forapic_round_robin
vcpu not ready forapic_round_robinSecond time nothing, only process was run at 200% CPU:
top - 06:23:14 up 4 days, 11:06, 1 user, load average: 2.26, 2.15, 2.18
Tasks: 126 total, 1 running, 125 sleeping, 0 stopped, 0 zombie
Cpu(s): 50.2%us, 0.4%sy, 0.0%ni, 49.1%id, 0.2%wa, 0.0%hi, 0.1%si, 0.0%st
Quoted 6 lines
Mem: 8047368k total, 8004516k used, 42852k free, 1507160k buffers Swap: 8388600k total, 57284k used, 8331316k free, 79700k cachedPID USER PR NI VIRT RES SHR S %CPU %MEM TIME+ COMMAND 17110 root 20 0 4417m 3.9g 1464 S 201.3 50.9 1326:34 qemu-kvm 9886 root 20 0 2519m 1.9g 1376 S 1.7 25.1 72:40.73 qemu-kvm
What's the command line you used to start the guests?
Quoted 5 lines
Serial console without response too in boch cases, no ping to guest.
My current configuration is an fully updated Fedora 11 host and updated Fedora 10 guest. KVM is from package qemu-kvm-0.10.5-3.fc11.x86_64.
Amit
Quoted 6 lines · Amit Shah
Quoted 3 lines · Ján ONDREJ (SAL)
PID USER PR NI VIRT RES SHR S %CPU %MEM TIME+ COMMAND 17110 root 20 0 4417m 3.9g 1464 S 201.3 50.9 1326:34 qemu-kvm 9886 root 20 0 2519m 1.9g 1376 S 1.7 25.1 72:40.73 qemu-kvmWhat's the command line you used to start the guests?
Guest was started using libvirt.
Looks that problem is somewhere in bounce code, more info in another thread:
http://marc.info/?l=kvm&m=124756938002626&w=2
My CPU usage is growing after kernel panic. With panic=60 my guest is restarted and runs some time again.
I am now experiencing with IDE dirves instead of virtio, so I can't send you qemu-kvm original command line. With IDE drives there was no problem tonight.
Thank you.
SAL
Quoted 10 lines · Ján ONDREJ (SAL)
Quoted 6 lines · Amit Shah
Quoted 3 lines · Ján ONDREJ (SAL)
PID USER PR NI VIRT RES SHR S %CPU %MEM TIME+ COMMAND 17110 root 20 0 4417m 3.9g 1464 S 201.3 50.9 1326:34 qemu-kvm 9886 root 20 0 2519m 1.9g 1376 S 1.7 25.1 72:40.73 qemu-kvmWhat's the command line you used to start the guests?
Guest was started using libvirt.
Quoted 8 lines
Looks that problem is somewhere in bounce code, more info in another thread:
http://marc.info/?l=kvm&m=124756938002626&w=2
My CPU usage is growing after kernel panic. With panic=60 my guest is restarted and runs some time again.I am now experiencing with IDE dirves instead of virtio, so I can't send you qemu-kvm original command line. With IDE drives there was no problem tonight.
OK, the virtio-block code has a known bug which you might be hitting.
Amit